@@ -1,36 +1,111 @@
-﻿define(['paperdialoghelper', 'paper-checkbox', 'paper-dialog', 'paper-input', 'paper-item-body', 'paper-icon-item'], function (paperDialogHelper) {
+﻿define(['paperdialoghelper', 'paper-checkbox', 'paper-dialog', 'paper-input', 'paper-item-body', 'paper-icon-item', 'paper-textarea', 'paper-fab'], function (paperDialogHelper) {
 
-    var currentDialog;
+    var currentContext;
     var metadataEditorInfo;
     var currentItem;
 
-    function onWebSocketMessageReceived(e, data) {
+    function closeDialog(isSubmitted) {
 
-        var msg = data;
-
-        if (msg.MessageType === "LibraryChanged") {
-
-            if (msg.Data.ItemsUpdated.indexOf(currentItem.Id) != -1) {
-
-                console.log('Item updated - reloading metadata');
-                reload(currentDialog, currentItem.Id);
-            }
+        if (currentContext.tagName == 'PAPER-DIALOG') {
+            paperDialogHelper.close(currentContext);
         }
     }
 
-    function bindItemChanged() {
+    function submitUpdatedItem(form, item) {
 
-        Events.on(ApiClient, "websocketmessage", onWebSocketMessageReceived);
+        function afterContentTypeUpdated() {
+
+            require(['toast'], function (toast) {
+                toast(Globalize.translate('MessageItemSaved'));
+            });
+
+            Dashboard.hideLoadingMsg();
+            closeDialog(true);
+        }
+
+        ApiClient.updateItem(item).then(function () {
+
+            var newContentType = $('#selectContentType', form).val() || '';
+
+            if ((metadataEditorInfo.ContentType || '') != newContentType) {
+
+                ApiClient.ajax({
+
+                    url: ApiClient.getUrl('Items/' + item.Id + '/ContentType', {
+                        ContentType: newContentType
+                    }),
+
+                    type: 'POST'
+
+                }).then(function () {
+                    afterContentTypeUpdated();
+                });
+
+            } else {
+                afterContentTypeUpdated();
+            }
+
+        });
     }
 
-    function unbindItemChanged() {
-
-        Events.off(ApiClient, "websocketmessage", onWebSocketMessageReceived);
+    function getSelectedAirDays(form) {
+        return $('.chkAirDay:checked', form).map(function () {
+            return this.getAttribute('data-day');
+        }).get();
     }
 
-    function closeDialog(isSubmitted) {
+    function getAlbumArtists(form) {
 
-        paperDialogHelper.close(currentDialog);
+        return $('#txtAlbumArtist', form).val().trim().split(';').filter(function (s) {
+
+            return s.length > 0;
+
+        }).map(function (a) {
+
+            return {
+                Name: a
+            };
+        });
+    }
+
+    function getArtists(form) {
+
+        return $('#txtArtist', form).val().trim().split(';').filter(function (s) {
+
+            return s.length > 0;
+
+        }).map(function (a) {
+
+            return {
+                Name: a
+            };
+        });
+    }
+
+    function getDateFromForm(form, element, property) {
+
+        var val = $(element, form).val();
+
+        if (!val) {
+            return null;
+        }
+
+        if (currentItem[property]) {
+
+            var date = parseISO8601Date(currentItem[property], { toLocal: true });
+
+            var parts = date.toISOString().split('T');
+
+            // If the date is the same, preserve the time
+            if (parts[0].indexOf(val) == 0) {
+
+                var iso = parts[1];
+
+                val += 'T' + iso;
+            }
+        }
+
+        return val;
     }
 
     function onSubmit() {
@@ -39,6 +114,98 @@
 
         var form = this;
 
+        try {
+            var item = {
+                Id: currentItem.Id,
+                Name: $('#txtName', form).val(),
+                ForcedSortName: $('#txtSortName', form).val(),
+                DisplayMediaType: $('#txtDisplayMediaType', form).val(),
+                CommunityRating: $('#txtCommunityRating', form).val(),
+                VoteCount: $('#txtCommunityVoteCount', form).val(),
+                HomePageUrl: $('#txtHomePageUrl', form).val(),
+                Budget: $('#txtBudget', form).val(),
+                Revenue: $('#txtRevenue', form).val(),
+                CriticRating: $('#txtCriticRating', form).val(),
+                CriticRatingSummary: $('#txtCriticRatingSummary', form).val(),
+                IndexNumber: $('#txtIndexNumber', form).val() || null,
+                DisplaySpecialsWithSeasons: form.querySelector('#chkDisplaySpecialsInline').checked,
+                AbsoluteEpisodeNumber: $('#txtAbsoluteEpisodeNumber', form).val(),
+                DvdEpisodeNumber: $('#txtDvdEpisodeNumber', form).val(),
+                DvdSeasonNumber: $('#txtDvdSeasonNumber', form).val(),
+                AirsBeforeSeasonNumber: $('#txtAirsBeforeSeason', form).val(),
+                AirsAfterSeasonNumber: $('#txtAirsAfterSeason', form).val(),
+                AirsBeforeEpisodeNumber: $('#txtAirsBeforeEpisode', form).val(),
+                ParentIndexNumber: $('#txtParentIndexNumber', form).val() || null,
+                DisplayOrder: $('#selectDisplayOrder', form).val(),
+                Players: $('#txtPlayers', form).val(),
+                Album: $('#txtAlbum', form).val(),
+                AlbumArtist: getAlbumArtists(form),
+                ArtistItems: getArtists(form),
+                Metascore: $('#txtMetascore', form).val(),
+                AwardSummary: $('#txtAwardSummary', form).val(),
+                Overview: $('#txtOverview', form).val(),
+                ShortOverview: $('#txtShortOverview', form).val(),
+                Status: $('#selectStatus', form).val(),
+                AirDays: getSelectedAirDays(form),
+                AirTime: $('#txtAirTime', form).val(),
+                Genres: editableListViewValues($("#listGenres", form)),
+                ProductionLocations: editableListViewValues($("#listCountries", form)),
+                Tags: editableListViewValues($("#listTags", form)),
+                Keywords: editableListViewValues($("#listKeywords", form)),
+                Studios: editableListViewValues($("#listStudios", form)).map(function (element) { return { Name: element }; }),
+
+                PremiereDate: getDateFromForm(form, '#txtPremiereDate', 'PremiereDate'),
+                DateCreated: getDateFromForm(form, '#txtDateAdded', 'DateCreated'),
+                EndDate: getDateFromForm(form, '#txtEndDate', 'EndDate'),
+                ProductionYear: $('#txtProductionYear', form).val(),
+                AspectRatio: $('#txtOriginalAspectRatio', form).val(),
+                Video3DFormat: $('#select3dFormat', form).val(),
+
+                OfficialRating: $('#selectOfficialRating', form).val(),
+                CustomRating: $('#selectCustomRating', form).val(),
+                People: currentItem.People,
+                LockData: form.querySelector("#chkLockData").checked,
+                LockedFields: $('.selectLockedField', form).get().filter(function (c) {
+                    return !c.checked;
+                }).map(function (c) {
+                    return c.getAttribute('data-value');
+                })
+            };
+
+            item.ProviderIds = $.extend({}, currentItem.ProviderIds || {});
+
+            $('.txtExternalId', form).each(function () {
+
+                var providerkey = this.getAttribute('data-providerkey');
+
+                item.ProviderIds[providerkey] = this.value;
+            });
+
+            item.PreferredMetadataLanguage = $('#selectLanguage', form).val();
+            item.PreferredMetadataCountryCode = $('#selectCountry', form).val();
+
+            if (currentItem.Type == "Person") {
+
+                var placeOfBirth = $('#txtPlaceOfBirth', form).val();
+
+                item.ProductionLocations = placeOfBirth ? [placeOfBirth] : [];
+            }
+
+            if (currentItem.Type == "Series") {
+
+                // 600000000
+                var seriesRuntime = $('#txtSeriesRuntime', form).val();
+                item.RunTimeTicks = seriesRuntime ? (seriesRuntime * 600000000) : null;
+            }
+
+            var tagline = $('#txtTagline', form).val();
+            item.Taglines = tagline ? [tagline] : [];
+
+            submitUpdatedItem(form, item);
+        } catch (err) {
+            alert(err);
+        }
+
         // Disable default form submission
         return false;
     }
@@ -65,15 +232,12 @@
         require(['prompt'], function (prompt) {
 
             prompt({
-                text: 'Value:',
-                callback: function (text) {
-                    if (text == '') return;
-                    var parent = $(source).parents('.editableListviewContainer');
-                    var list = parent.find('.paperList');
-                    var items = editableListViewValues(list);
-                    items.push(text);
-                    populateListView(list[0], items, sortCallback);
-                }
+                label: 'Value:'
+            }).then(function (text) {
+                var list = $(source).parents('.editableListviewContainer').find('.paperList');
+                var items = editableListViewValues(list);
+                items.push(text);
+                populateListView(list[0], items, sortCallback);
             });
         });
     }
@@ -82,6 +246,186 @@
         $(source).parents('paper-icon-item').remove();
     }
 
+    function editPerson(context, person, index) {
+
+        require(['components/metadataeditor/personeditor'], function (personeditor) {
+
+            personeditor.show(person).then(function (updatedPerson) {
+
+                var isNew = index == -1;
+
+                if (isNew) {
+                    currentItem.People.push(updatedPerson);
+                }
+
+                populatePeople(context, currentItem.People);
+            });
+        });
+    }
+
+    function showRefreshMenu(context, button) {
+
+        var items = [];
+
+        items.push({
+            name: Globalize.translate('ButtonLocalRefresh'),
+            id: 'local',
+            ironIcon: 'refresh'
+        });
+
+        items.push({
+            name: Globalize.translate('ButtonAddMissingData'),
+            id: 'missing',
+            ironIcon: 'refresh'
+        });
+
+        items.push({
+            name: Globalize.translate('ButtonFullRefresh'),
+            id: 'full',
+            ironIcon: 'refresh'
+        });
+
+        require(['actionsheet'], function (actionsheet) {
+
+            actionsheet.show({
+                items: items,
+                positionTo: button,
+                callback: function (id) {
+
+                    if (id) {
+                    
+                        Dashboard.showLoadingMsg();
+                        // For now this is a hack
+                        setTimeout(function () {
+                            Dashboard.hideLoadingMsg();
+                        }, 5000);
+                    }
+
+                    switch (id) {
+
+                        case 'local':
+                            ApiClient.refreshItem(currentItem.Id, {
+                                Recursive: true,
+                                ImageRefreshMode: 'None',
+                                MetadataRefreshMode: 'ValidationOnly',
+                                ReplaceAllImages: false,
+                                ReplaceAllMetadata: false
+                            });
+                            break;
+                        case 'missing':
+                            ApiClient.refreshItem(currentItem.Id, {
+                                Recursive: true,
+                                ImageRefreshMode: 'FullRefresh',
+                                MetadataRefreshMode: 'FullRefresh',
+                                ReplaceAllImages: false,
+                                ReplaceAllMetadata: false
+                            });
+                            break;
+                        case 'full':
+                            ApiClient.refreshItem(currentItem.Id, {
+                                Recursive: true,
+                                ImageRefreshMode: 'FullRefresh',
+                                MetadataRefreshMode: 'FullRefresh',
+                                ReplaceAllImages: false,
+                                ReplaceAllMetadata: true
+                            });
+                            break;
+                        default:
+                            break;
+                    }
+                }
+            });
+
+        });
+
+    }
+
+    function showMoreMenu(context, button) {
+
+        var items = [];
+
+        items.push({
+            name: Globalize.translate('ButtonEditImages'),
+            id: 'images',
+            ironIcon: 'photo'
+        });
+
+        items.push({
+            name: Globalize.translate('ButtonIdentify'),
+            id: 'identify',
+            ironIcon: 'info'
+        });
+
+        items.push({
+            name: Globalize.translate('ButtonRefresh'),
+            id: 'refresh',
+            ironIcon: 'refresh'
+        });
+
+        require(['actionsheet'], function (actionsheet) {
+
+            actionsheet.show({
+                items: items,
+                positionTo: button,
+                callback: function (id) {
+
+                    switch (id) {
+
+                        case 'identify':
+                            LibraryBrowser.identifyItem(currentItem.Id);
+                            break;
+                        case 'refresh':
+                            showRefreshMenu(context, button);
+                            break;
+                        case 'images':
+                            LibraryBrowser.editImages(currentItem.Id);
+                            break;
+                        default:
+                            break;
+                    }
+                }
+            });
+
+        });
+
+    }
+
+    function onWebSocketMessageReceived(e, data) {
+
+        var msg = data;
+
+        if (msg.MessageType === "LibraryChanged") {
+
+            if (msg.Data.ItemsUpdated.indexOf(currentItem.Id) != -1) {
+
+                console.log('Item updated - reloading metadata');
+                reload(currentContext, currentItem.Id);
+            }
+        }
+    }
+
+    function bindItemChanged(context) {
+
+        Events.on(ApiClient, "websocketmessage", onWebSocketMessageReceived);
+    }
+
+    function unbindItemChanged(context) {
+
+        Events.off(ApiClient, "websocketmessage", onWebSocketMessageReceived);
+    }
+
+    function onEditorClick(e) {
+        var btnRemoveFromEditorList = parentWithClass(e.target, 'btnRemoveFromEditorList');
+        if (btnRemoveFromEditorList) {
+            removeElementFromListview(btnRemoveFromEditorList);
+        }
+
+        var btnAddTextItem = parentWithClass(e.target, 'btnAddTextItem');
+        if (btnAddTextItem) {
+            addElementToEditableListview(btnAddTextItem);
+        }
+    }
+
     function init(context) {
 
         $('.btnCancel', context).on('click', function () {
@@ -89,21 +433,39 @@
             closeDialog(false);
         });
 
-        context.addEventListener('click', function (e) {
-
-            var btnRemoveFromEditorList = parentWithClass(e.target, 'btnRemoveFromEditorList');
-            if (btnRemoveFromEditorList) {
-                removeElementFromListview(btnRemoveFromEditorList);
-            }
-
-            var btnAddTextItem = parentWithClass(e.target, 'btnAddTextItem');
-            if (btnAddTextItem) {
-                addElementToEditableListview(btnAddTextItem);
-            }
+        context.querySelector('.btnMore').addEventListener('click', function (e) {
 
+            showMoreMenu(context, e.target);
         });
 
+        context.querySelector('.btnHeaderSave').addEventListener('click', function (e) {
+
+            context.querySelector('.btnSave').click();
+        });
+
+        context.querySelector('#chkLockData').addEventListener('click', function (e) {
+
+            if (!e.target.checked) {
+                $('.providerSettingsContainer').show();
+            } else {
+                $('.providerSettingsContainer').hide();
+            }
+        });
+
+        context.removeEventListener('click', onEditorClick);
+        context.addEventListener('click', onEditorClick);
+
         $('form', context).off('submit', onSubmit).on('submit', onSubmit);
+
+        $("#btnAddPerson", context).on('click', function (event, data) {
+
+            editPerson(context, {}, -1);
+        });
+
+        // For now this is only supported in dialog mode because we have a way of knowing when it closes
+        if (currentContext.tagName == 'PAPER-DIALOG') {
+            bindItemChanged(context);
+        }
     }
 
     function getItem(itemId) {
@@ -119,10 +481,7 @@
             return ApiClient.getJSON(ApiClient.getUrl('Items/' + itemId + '/MetadataEditor'));
         }
 
-        return new Promise(function (resolve, reject) {
-
-            resolve({});
-        });
+        return Promise.resolve({});
     }
 
     function populateCountries(select, allCountries) {
@@ -392,13 +751,13 @@
 
         if (item.Type == "Person") {
             context.querySelector('#txtProductionYear').label = Globalize.translate('LabelBirthYear');
-            context.querySelector("#txtPremiereDate").innerHTML = Globalize.translate('LabelBirthDate');
-            context.querySelector("#txtEndDate").innerHTML = Globalize.translate('LabelDeathDate');
+            context.querySelector("#txtPremiereDate").label = Globalize.translate('LabelBirthDate');
+            context.querySelector("#txtEndDate").label = Globalize.translate('LabelDeathDate');
             $('#fldPlaceOfBirth', context).show();
         } else {
             context.querySelector('#txtProductionYear').label = Globalize.translate('LabelYear');
-            context.querySelector("#txtPremiereDate").innerHTML = Globalize.translate('LabelReleaseDate');
-            context.querySelector("#txtEndDate").innerHTML = Globalize.translate('LabelEndDate');
+            context.querySelector("#txtPremiereDate").label = Globalize.translate('LabelReleaseDate');
+            context.querySelector("#txtEndDate").label = Globalize.translate('LabelEndDate');
             $('#fldPlaceOfBirth', context).hide();
         }
 
@@ -505,9 +864,9 @@
         var chkLockData = context.querySelector("#chkLockData");
         chkLockData.checked = lockData;
         if (chkLockData.checked) {
-            $('#providerSettingsContainer', context).hide();
+            $('.providerSettingsContainer', context).hide();
         } else {
-            $('#providerSettingsContainer', context).show();
+            $('.providerSettingsContainer', context).show();
         }
         populateInternetProviderSettings(context, item, item.LockedFields);
 
@@ -690,8 +1049,6 @@
             html += '<paper-icon-button icon="delete" data-index="' + i + '" class="btnRemoveFromEditorList"></paper-icon-button>';
 
             html += '</paper-icon-item>';
-
-            //html += '<li data-mini="true"><a class="data">' + items[i] + '</a><a href="#" onclick="EditItemMetadataPage.removeElementFromListview(this)" class="btnRemoveFromEditorList"></a></li>';
         }
 
         list.innerHTML = html;
@@ -702,34 +1059,36 @@
         var lastType = '';
         var html = '';
 
-        var elem = $('#peopleList', context);
+        var elem = context.querySelector('#peopleList');
 
         for (var i = 0, length = people.length; i < length; i++) {
 
             var person = people[i];
 
-            var type = person.Type || Globalize.translate('PersonTypePerson');
+            html += '<paper-icon-item>';
 
-            if (type != lastType) {
-                html += '<li data-role="list-divider">' + type + '</li>';
-                lastType = type;
-            }
+            html += '<paper-fab class="btnEditPerson" data-index="' + i + '" mini style="background-color:#444;" icon="person" item-icon></paper-fab>';
 
-            html += '<li><a class="btnEditPerson" href="#" data-index="' + i + '">';
+            html += '<paper-item-body>';
+            html += '<a class="btnEditPerson clearLink" href="#" data-index="' + i + '">';
 
-            html += '<h3>' + (person.Name || '') + '</h3>';
+            html += '<div class="textValue">';
+            html += (person.Name || '');
+            html += '</div>';
 
             if (person.Role && person.Role != lastType) {
-                html += '<p>' + (person.Role) + '</p>';
+                html += '<div secondary>' + (person.Role) + '</div>';
             }
+
             html += '</a>';
+            html += '</paper-item-body>';
 
-            html += '<a class="btnDeletePerson" href="#" data-icon="delete" data-index="' + i + '">' + Globalize.translate('Delete') + '</a>';
+            html += '<paper-icon-button icon="delete" data-index="' + i + '" class="btnDeletePerson"></paper-icon-button>';
 
-            html += '</li>';
+            html += '</paper-icon-item>';
         }
 
-        //elem.html(html).listview('refresh');
+        elem.innerHTML = html;
 
         $('.btnDeletePerson', elem).on('click', function () {
 
@@ -762,7 +1121,7 @@
     }
 
     function populateInternetProviderSettings(context, item, lockedFields) {
-        var container = $('#providerSettingsContainer', context);
+        var container = $('.providerSettingsContainer', context);
         lockedFields = lockedFields || new Array();
 
         var metadatafields = [
@@ -803,7 +1162,6 @@
 
     function reload(context, itemId) {
 
-        unbindItemChanged();
         Dashboard.showLoadingMsg();
 
         Promise.all([getItem(itemId), getEditorConfig(itemId)]).then(function (responses) {
@@ -847,7 +1205,6 @@
             }
 
             Dashboard.hideLoadingMsg();
-            bindItemChanged(context);
         });
     }
 
@@ -865,7 +1222,7 @@
                     var template = this.response;
                     var dlg = paperDialogHelper.createDialog({
                         removeOnClose: true,
-                        size: 'small'
+                        size: 'medium'
                     });
 
                     dlg.classList.add('ui-body-b');
@@ -883,16 +1240,43 @@
                     paperDialogHelper.open(dlg);
 
                     dlg.addEventListener('iron-overlay-closed', function () {
+                        unbindItemChanged(dlg);
                         resolve();
                     });
 
-                    currentDialog = dlg;
+                    currentContext = dlg;
 
                     init(dlg);
 
                     reload(dlg, itemId);
                 }
 
+                xhr.send();
+            });
+        },
+
+        embed: function (elem, itemId) {
+            return new Promise(function (resolve, reject) {
+
+                Dashboard.showLoadingMsg();
+
+                var xhr = new XMLHttpRequest();
+                xhr.open('GET', 'components/metadataeditor/metadataeditor.template.html', true);
+
+                xhr.onload = function (e) {
+
+                    var template = this.response;
+
+                    elem.innerHTML = Globalize.translateDocument(template);
+
+                    elem.querySelector('.btnCancel').classList.add('hide');
+
+                    currentContext = elem;
+
+                    init(elem);
+                    reload(elem, itemId);
+                }
+
                 xhr.send();
             });
         }
