@@ -64,7 +64,7 @@
         });
     }
 
-    function showPlayerSelection(button) {
+    function showPlayerSelection(button, enableHistory) {
 
         var playerInfo = MediaController.getPlayerInfo();
 
@@ -88,7 +88,7 @@
                 return {
                     name: name,
                     id: t.id,
-                    ironIcon: 'tablet-android'
+                    ironIcon: playerInfo.id == t.id ? 'check' : null
                 };
 
             });
@@ -101,6 +101,7 @@
                     title: Globalize.translate('HeaderSelectPlayer'),
                     items: menuItems,
                     positionTo: button,
+                    enableHistory: enableHistory !== false,
                     callback: function (id) {
 
                         var target = targets.filter(function (t) {
@@ -801,15 +802,13 @@
 
         self.showPlaybackInfoErrorMessage = function (errorCode) {
 
-            // This timeout is messy, but if jqm is in the act of hiding a popup, it will not show a new one
-            // If we're coming from the popup play menu, this will be a problem
-
-            setTimeout(function () {
-                Dashboard.alert({
-                    message: Globalize.translate('MessagePlaybackError' + errorCode),
-                    title: Globalize.translate('HeaderPlaybackError')
+            require(['alert'], function (alert) {
+                alert({
+                    title: Globalize.translate('HeaderPlaybackError'),
+                    text: Globalize.translate('MessagePlaybackError' + errorCode),
+                    type: 'error'
                 });
-            }, 300);
+            });
 
         };
 
