@@ -404,7 +404,7 @@ var Dashboard = {
         }
 
         if (options.forceShow) {
-            elem.slideDown(400);
+            elem.show();
         }
 
         elem.html(options.html);
@@ -427,7 +427,7 @@ var Dashboard = {
             setTimeout(function () { // give the DOM time to catch up
 
                 if (!parentElem.html()) {
-                    footer.slideUp();
+                    footer.hide();
                 }
 
             }, 50);
@@ -458,39 +458,27 @@ var Dashboard = {
     showLoadingMsg: function () {
 
         Dashboard.loadingVisible = true;
-        var elem = document.querySelector('.docspinner');
 
-        if (elem) {
-
-            // This is just an attempt to prevent the fade-in animation from running repeating and causing flickering
-            elem.active = true;
-            elem.classList.remove('hide');
-
-        } else if (!Dashboard.loadingAdded) {
-
-            Dashboard.loadingAdded = true;
-
-            require(['paper-spinner'], function () {
-                elem = document.createElement("paper-spinner");
-                elem.classList.add('docspinner');
-
-                document.body.appendChild(elem);
-                elem.active = Dashboard.loadingVisible == true;
-            });
-        }
+        require(['loading'], function (loading) {
+            if (Dashboard.loadingVisible) {
+                loading.show();
+            } else {
+                loading.hide();
+            }
+        });
     },
 
     hideLoadingMsg: function () {
 
         Dashboard.loadingVisible = false;
 
-        var elem = document.querySelector('.docspinner');
-
-        if (elem) {
-
-            elem.active = false;
-            elem.classList.add('hide');
-        }
+        require(['loading'], function (loading) {
+            if (Dashboard.loadingVisible) {
+                loading.show();
+            } else {
+                loading.hide();
+            }
+        });
     },
 
     getModalLoadingMsg: function () {
@@ -523,119 +511,41 @@ var Dashboard = {
 
         Dashboard.hideLoadingMsg();
 
-        Dashboard.alert(Globalize.translate('MessageSettingsSaved'));
+        require(['toast'], function (toast) {
+            toast(Globalize.translate('MessageSettingsSaved'));
+        });
     },
 
     processServerConfigurationUpdateResult: function (result) {
 
         Dashboard.hideLoadingMsg();
 
-        Dashboard.alert(Globalize.translate('MessageSettingsSaved'));
+        require(['toast'], function (toast) {
+            toast(Globalize.translate('MessageSettingsSaved'));
+        });
     },
 
     alert: function (options) {
 
         if (typeof options == "string") {
 
-            require(['paper-toast'], function () {
-                var message = options;
+            require(['toast'], function (toast) {
 
-                Dashboard.toastId = Dashboard.toastId || 0;
-
-                var id = 'toast' + (Dashboard.toastId++);
-
-                var elem = document.createElement("paper-toast");
-                elem.setAttribute('text', message);
-                elem.id = id;
-
-                document.body.appendChild(elem);
-
-                // This timeout is obviously messy but it's unclear how to determine when the webcomponent is ready for use
-                // element onload never fires
-                setTimeout(function () {
-                    elem.show();
-                }, 300);
-
-                setTimeout(function () {
-                    elem.parentNode.removeChild(elem);
-                }, 5300);
+                toast({
+                    text: options
+                });
 
             });
 
             return;
         }
 
-        // Cordova
-        if (navigator.notification && navigator.notification.alert && options.message.indexOf('<') == -1) {
-
-            navigator.notification.alert(options.message, options.callback || function () { }, options.title || Globalize.translate('HeaderAlert'));
-
-        } else {
-            require(['paper-dialog', 'fade-in-animation', 'fade-out-animation'], function () {
-                Dashboard.confirmInternal(options.message, options.title || Globalize.translate('HeaderAlert'), false, options.callback);
-            });
-        }
-    },
-
-    confirm: function (message, title, callback) {
-
-        // Cordova
-        if (navigator.notification && navigator.notification.confirm && message.indexOf('<') == -1) {
-
-            var buttonLabels = [Globalize.translate('ButtonOk'), Globalize.translate('ButtonCancel')];
-
-            navigator.notification.confirm(message, function (index) {
-
-                callback(index == 1);
-
-            }, title || Globalize.translate('HeaderConfirm'), buttonLabels.join(','));
-
-        } else {
-
-            require(['paper-dialog', 'fade-in-animation', 'fade-out-animation'], function () {
-                Dashboard.confirmInternal(message, title, true, callback);
-            });
-        }
-    },
-
-    confirmInternal: function (message, title, showCancel, callback) {
-
-        var dlg = document.createElement('paper-dialog');
-
-        dlg.setAttribute('with-backdrop', 'with-backdrop');
-        dlg.setAttribute('role', 'alertdialog');
-        dlg.entryAnimation = 'fade-in-animation';
-        dlg.exitAnimation = 'fade-out-animation';
-        dlg.setAttribute('with-backdrop', 'with-backdrop');
-
-        var html = '';
-        html += '<h2>' + title + '</h2>';
-        html += '<div>' + message + '</div>';
-        html += '<div class="buttons">';
-
-        html += '<paper-button class="btnConfirm" dialog-confirm autofocus>' + Globalize.translate('ButtonOk') + '</paper-button>';
-
-        if (showCancel) {
-            html += '<paper-button dialog-dismiss>' + Globalize.translate('ButtonCancel') + '</paper-button>';
-        }
-
-        html += '</div>';
-
-        dlg.innerHTML = html;
-        document.body.appendChild(dlg);
-
-        // Has to be assigned a z-index after the call to .open() 
-        dlg.addEventListener('iron-overlay-closed', function (e) {
-
-            var confirmed = dlg.closingReason.confirmed;
-            dlg.parentNode.removeChild(dlg);
-
-            if (callback) {
-                callback(confirmed);
-            }
+        require(['alert'], function (alert) {
+            alert({
+                title: options.title || Globalize.translate('HeaderAlert'),
+                text: options.message
+            }).then(options.callback || function () { });
         });
-
-        dlg.open();
     },
 
     refreshSystemInfoFromServer: function () {
@@ -703,36 +613,7 @@ var Dashboard = {
 
     showUserFlyout: function () {
 
-        require(['jqmpanel'], function () {
-            var html = '<div data-role="panel" data-position="right" data-display="overlay" id="userFlyout" data-position-fixed="true" data-theme="a">';
-
-            html += '<h3 class="userHeader">';
-
-            html += '</h3>';
-
-            html += '<form>';
-
-            html += '<p class="preferencesContainer"></p>';
-
-            html += '<p><button data-mini="true" type="button" onclick="Dashboard.logout();" data-icon="lock">' + Globalize.translate('ButtonSignOut') + '</button></p>';
-
-            html += '</form>';
-            html += '</div>';
-
-            $(document.body).append(html);
-
-            var userFlyout = document.querySelector('#userFlyout');
-            ImageLoader.lazyChildren(userFlyout);
-
-            $(userFlyout).panel({}).panel("open").on("panelclose", function () {
-
-                $(this).off("panelclose").remove();
-            });
-
-            ConnectionManager.user(window.ApiClient).then(function (user) {
-                Dashboard.updateUserFlyout(userFlyout, user);
-            });
-        });
+        Dashboard.navigate('mypreferencesmenu.html?userId=' + ApiClient.getCurrentUserId());
     },
 
     updateUserFlyout: function (elem, user) {
@@ -740,7 +621,7 @@ var Dashboard = {
         var html = '';
         var imgWidth = 48;
 
-        if (user.imageUrl && AppInfo.enableUserImage) {
+        if (user.imageUrl) {
             var url = user.imageUrl;
 
             if (user.supportsImageParams) {
@@ -770,18 +651,12 @@ var Dashboard = {
 
         if (!apiClient) {
 
-            return new Promise(function (resolve, reject) {
-
-                reject();
-            });
+            return Promise.reject();
         }
 
         var cachedInfo = Dashboard.pluginSecurityInfo;
         if (cachedInfo) {
-            return new Promise(function (resolve, reject) {
-
-                resolve(cachedInfo);
-            });
+            return Promise.resolve(cachedInfo);
         }
 
         return apiClient.ajax({
@@ -1592,7 +1467,6 @@ var AppInfo = {};
         if (!AppInfo.hasLowImageBandwidth) {
             AppInfo.enableStudioTabs = true;
             AppInfo.enableTvEpisodesTab = true;
-            AppInfo.enableMovieTrailersTab = true;
         }
 
         AppInfo.supportsExternalPlayers = true;
@@ -1617,17 +1491,15 @@ var AppInfo = {};
         // This doesn't perform well on iOS
         AppInfo.enableHeadRoom = !isIOS;
 
-        AppInfo.supportsDownloading = !(AppInfo.isNativeApp && isIOS);
+        AppInfo.supportsDownloading = !(AppInfo.isNativeApp);
 
         // This currently isn't working on android, unfortunately
         AppInfo.supportsFileInput = !(AppInfo.isNativeApp && isAndroid);
 
-        AppInfo.enableUserImage = true;
         AppInfo.hasPhysicalVolumeButtons = isCordova || isMobile;
         AppInfo.enableBackButton = isIOS && (window.navigator.standalone || AppInfo.isNativeApp);
 
         AppInfo.supportsSyncPathSetting = isCordova && isAndroid;
-        AppInfo.supportsUserDisplayLanguageSetting = Dashboard.isConnectMode() && !isCordova;
 
         if (isCordova && isIOS) {
             AppInfo.moreIcon = 'more-horiz';
@@ -1638,7 +1510,15 @@ var AppInfo = {};
 
     function initializeApiClient(apiClient) {
 
-        apiClient.enableAppStorePolicy = AppInfo.enableAppStorePolicy;
+        if (AppInfo.enableAppStorePolicy) {
+            apiClient.getAvailablePlugins = function () {
+                return Promise.resolve([]);
+            };
+            apiClient.getInstalledPlugins = function () {
+                return Promise.resolve([]);
+            };
+        }
+
         apiClient.getDefaultImageQuality = Dashboard.getDefaultImageQuality;
         apiClient.normalizeImageOptions = Dashboard.normalizeImageOptions;
 
@@ -1658,6 +1538,9 @@ var AppInfo = {};
 
     function onApiClientCreated(e, newApiClient) {
         initializeApiClient(newApiClient);
+
+        // This is not included in jQuery slim
+        $.ajax = newApiClient.ajax;
     }
 
     //localStorage.clear();
@@ -1689,7 +1572,7 @@ var AppInfo = {};
                         Dashboard.showLoadingMsg();
 
                         return ConnectionManager.connectToServer(server).then(function (result) {
-                            Dashboard.showLoadingMsg();
+                            Dashboard.hideLoadingMsg();
 
                             if (result.State == MediaBrowser.ConnectionState.SignedIn) {
                                 window.ApiClient = result.ApiClient;
@@ -1766,10 +1649,6 @@ var AppInfo = {};
             elem.classList.add('tvEpisodesTabDisabled');
         }
 
-        if (!AppInfo.enableMovieTrailersTab) {
-            elem.classList.add('movieTrailersTabDisabled');
-        }
-
         if (!AppInfo.enableSupporterMembership) {
             elem.classList.add('supporterMembershipDisabled');
         }
@@ -1810,18 +1689,25 @@ var AppInfo = {};
         return obj;
     }
 
-    function initRequire() {
-
-        var urlArgs = "v=" + (window.dashboardVersion || new Date().getDate());
+    function getBowerPath() {
 
         var bowerPath = "bower_components";
 
         // Put the version into the bower path since we can't easily put a query string param on html imports
         // Emby server will handle this
-        if (!Dashboard.isRunningInCordova()) {
+        if (Dashboard.isConnectMode() && !Dashboard.isRunningInCordova()) {
             bowerPath += window.dashboardVersion;
         }
 
+        return bowerPath;
+    }
+
+    function initRequire() {
+
+        var urlArgs = "v=" + (window.dashboardVersion || new Date().getDate());
+
+        var bowerPath = getBowerPath();
+
         var apiClientBowerPath = bowerPath + "/emby-apiclient";
         var embyWebComponentsBowerPath = bowerPath + '/emby-webcomponents';
 
@@ -1840,7 +1726,7 @@ var AppInfo = {};
             masonry: bowerPath + '/masonry/dist/masonry.pkgd.min',
             humanedate: 'components/humanedate',
             chromecasthelpers: 'components/chromecasthelpers',
-            jQuery: bowerPath + '/jquery/dist/jquery.min',
+            jQuery: bowerPath + '/jquery/dist/jquery.slim.min',
             fastclick: bowerPath + '/fastclick/lib/fastclick',
             events: apiClientBowerPath + '/events',
             credentialprovider: apiClientBowerPath + '/credentials',
@@ -1852,7 +1738,7 @@ var AppInfo = {};
             qualityoptions: embyWebComponentsBowerPath + "/qualityoptions",
             connectservice: apiClientBowerPath + '/connectservice',
             hammer: bowerPath + "/hammerjs/hammer.min",
-            performanceManager: embyWebComponentsBowerPath + "/performancemanager",
+            layoutManager: embyWebComponentsBowerPath + "/layoutmanager",
             focusManager: embyWebComponentsBowerPath + "/focusmanager",
             imageLoader: embyWebComponentsBowerPath + "/images/imagehelper"
         };
@@ -1868,19 +1754,16 @@ var AppInfo = {};
         paths.hlsjs = bowerPath + "/hls.js/dist/hls.min";
 
         if (Dashboard.isRunningInCordova()) {
-            paths.dialog = "cordova/dialog";
-            paths.prompt = "cordova/prompt";
             paths.sharingwidget = "cordova/sharingwidget";
             paths.serverdiscovery = "cordova/serverdiscovery";
             paths.wakeonlan = "cordova/wakeonlan";
             paths.actionsheet = "cordova/actionsheet";
         } else {
-            paths.dialog = "components/dialog";
-            paths.prompt = "components/prompt";
             paths.sharingwidget = "components/sharingwidget";
             paths.serverdiscovery = apiClientBowerPath + "/serverdiscovery";
             paths.wakeonlan = apiClientBowerPath + "/wakeonlan";
-            paths.actionsheet = "scripts/actionsheet";
+
+            define("actionsheet", [embyWebComponentsBowerPath + "/actionsheet/actionsheet"], returnFirstDependency);
         }
 
         // hack for an android test before browserInfo is loaded
@@ -1890,6 +1773,9 @@ var AppInfo = {};
             paths.appStorage = apiClientBowerPath + "/appstorage";
         }
 
+        paths.playlistManager = "scripts/playlistmanager";
+        paths.syncDialog = "scripts/sync";
+
         var sha1Path = bowerPath + "/cryptojslib/components/sha1-min";
         var md5Path = bowerPath + "/cryptojslib/components/md5-min";
         var shim = {};
@@ -1927,6 +1813,7 @@ var AppInfo = {};
         define("paper-slider", ["html!" + bowerPath + "/paper-slider/paper-slider.html"]);
         define("paper-tabs", ["html!" + bowerPath + "/paper-tabs/paper-tabs.html"]);
         define("paper-menu", ["html!" + bowerPath + "/paper-menu/paper-menu.html"]);
+        define("paper-material", ["html!" + bowerPath + "/paper-material/paper-material.html"]);
         define("paper-dialog", ["html!" + bowerPath + "/paper-dialog/paper-dialog.html"]);
         define("paper-dialog-scrollable", ["html!" + bowerPath + "/paper-dialog-scrollable/paper-dialog-scrollable.html"]);
         define("paper-button", ["html!" + bowerPath + "/paper-button/paper-button.html"]);
@@ -1953,26 +1840,31 @@ var AppInfo = {};
         define("paper-icon-item", ["html!" + bowerPath + "/paper-item/paper-icon-item.html"]);
         define("paper-item-body", ["html!" + bowerPath + "/paper-item/paper-item-body.html"]);
 
-        define("jstree", [bowerPath + "/jstree/dist/jstree.min", "css!thirdparty/jstree/themes/default/style.min.css"]);
+        define("paper-collapse-item", ["html!" + bowerPath + "/paper-collapse-item/paper-collapse-item.html"]);
+        define("emby-collapsible", ["html!" + bowerPath + "/emby-collapsible/emby-collapsible.html"]);
 
-        define("jqmicons", ['css!thirdparty/jquerymobile-1.4.5/jquery.mobile.custom.icons.css']);
-        define("jqmtable", ["thirdparty/jquerymobile-1.4.5/jqm.table", 'css!thirdparty/jquerymobile-1.4.5/jqm.table.css']);
+        define("jstree", [bowerPath + "/jstree/dist/jstree", "css!thirdparty/jstree/themes/default/style.min.css"]);
 
-        define("jqmwidget", ["thirdparty/jquerymobile-1.4.5/jqm.widget"]);
+        define('jqm', ['thirdparty/jquerymobile-1.4.5/jquery.mobile.custom.js']);
+        define("jqmbase", ['css!thirdparty/jquerymobile-1.4.5/jquery.mobile.custom.theme.css']);
+        define("jqmicons", ['jqmbase', 'css!thirdparty/jquerymobile-1.4.5/jquery.mobile.custom.icons.css']);
+        define("jqmtable", ['jqmbase', "thirdparty/jquerymobile-1.4.5/jqm.table", 'css!thirdparty/jquerymobile-1.4.5/jqm.table.css']);
 
-        define("jqmslider", ["thirdparty/jquerymobile-1.4.5/jqm.slider", 'css!thirdparty/jquerymobile-1.4.5/jqm.slider.css']);
+        define("jqmwidget", ['jqmbase', "thirdparty/jquerymobile-1.4.5/jqm.widget"]);
 
-        define("jqmpopup", ["thirdparty/jquerymobile-1.4.5/jqm.popup", 'css!thirdparty/jquerymobile-1.4.5/jqm.popup.css']);
+        define("jqmslider", ['jqmbase', "thirdparty/jquerymobile-1.4.5/jqm.slider", 'css!thirdparty/jquerymobile-1.4.5/jqm.slider.css']);
 
-        define("jqmlistview", ["thirdparty/jquerymobile-1.4.5/jqm.listview", 'css!thirdparty/jquerymobile-1.4.5/jqm.listview.css']);
+        define("jqmpopup", ['jqmbase', "thirdparty/jquerymobile-1.4.5/jqm.popup", 'css!thirdparty/jquerymobile-1.4.5/jqm.popup.css']);
 
-        define("jqmcontrolgroup", ["thirdparty/jquerymobile-1.4.5/jqm.controlgroup", 'css!thirdparty/jquerymobile-1.4.5/jqm.controlgroup.css']);
+        define("jqmlistview", ['jqmbase', 'css!thirdparty/jquerymobile-1.4.5/jqm.listview.css']);
 
-        define("jqmcollapsible", ["jqmicons", "thirdparty/jquerymobile-1.4.5/jqm.collapsible", 'css!thirdparty/jquerymobile-1.4.5/jqm.collapsible.css']);
+        define("jqmcontrolgroup", ['jqmbase', 'css!thirdparty/jquerymobile-1.4.5/jqm.controlgroup.css']);
 
-        define("jqmcheckbox", ["jqmicons", "thirdparty/jquerymobile-1.4.5/jqm.checkbox", 'css!thirdparty/jquerymobile-1.4.5/jqm.checkbox.css']);
+        define("jqmcollapsible", ['jqmbase', "jqmicons", "thirdparty/jquerymobile-1.4.5/jqm.collapsible", 'css!thirdparty/jquerymobile-1.4.5/jqm.collapsible.css']);
 
-        define("jqmpanel", ["thirdparty/jquerymobile-1.4.5/jqm.panel", 'css!thirdparty/jquerymobile-1.4.5/jqm.panel.css']);
+        define("jqmcheckbox", ['jqmbase', "jqmicons", "thirdparty/jquerymobile-1.4.5/jqm.checkbox", 'css!thirdparty/jquerymobile-1.4.5/jqm.checkbox.css']);
+
+        define("jqmpanel", ['jqmbase', "thirdparty/jquerymobile-1.4.5/jqm.panel", 'css!thirdparty/jquerymobile-1.4.5/jqm.panel.css']);
 
         define("iron-icon-set", ["html!" + bowerPath + "/iron-icon/iron-icon.html", "html!" + bowerPath + "/iron-iconset-svg/iron-iconset-svg.html"]);
         define("slideshow", [embyWebComponentsBowerPath + "/slideshow/slideshow"], returnFirstDependency);
@@ -1995,7 +1887,6 @@ var AppInfo = {};
             define("localassetmanager", [apiClientBowerPath + "/localassetmanager"]);
             define("fileupload", [apiClientBowerPath + "/fileupload"]);
         }
-        define("apiclient-deferred", ["legacy/deferred"]);
         define("connectionmanager", [apiClientBowerPath + "/connectionmanager"]);
 
         define("contentuploader", [apiClientBowerPath + "/sync/contentuploader"]);
@@ -2007,6 +1898,12 @@ var AppInfo = {};
         define("swiper", [bowerPath + "/Swiper/dist/js/swiper.min", "css!" + bowerPath + "/Swiper/dist/css/swiper.min"], returnFirstDependency);
 
         define("paperdialoghelper", [embyWebComponentsBowerPath + "/paperdialoghelper/paperdialoghelper"], returnFirstDependency);
+        define("loading", [embyWebComponentsBowerPath + "/loading/loading"], returnFirstDependency);
+        define("toast", [embyWebComponentsBowerPath + "/toast/toast"], returnFirstDependency);
+        define("scrollHelper", [embyWebComponentsBowerPath + "/scrollhelper"], returnFirstDependency);
+
+        define("appSettings", [embyWebComponentsBowerPath + "/appsettings"], updateAppSettings);
+        define("userSettings", [embyWebComponentsBowerPath + "/usersettings"], returnFirstDependency);
 
         // alias
         define("historyManager", [], function () {
@@ -2015,6 +1912,9 @@ var AppInfo = {};
                     state.navigate = false;
                     history.pushState(state, title, url);
                     jQuery.onStatePushed(state);
+                },
+                enableNativeHistory: function () {
+                    return true;
                 }
             };
         });
@@ -2032,6 +1932,59 @@ var AppInfo = {};
         define("connectionManager", [], function () {
             return ConnectionManager;
         });
+
+        define("globalize", [], function () {
+            return Globalize;
+        });
+
+        define('apiClientResolver', [], function () {
+            return function () {
+                return window.ApiClient;
+            };
+        });
+
+        define('dialogText', ['globalize'], getDialogText());
+    }
+
+    function updateAppSettings(appSettings) {
+
+        appSettings.enableExternalPlayers = function (val) {
+
+            if (val != null) {
+                appSettings.set('externalplayers', val.toString());
+            }
+
+            return appSettings.get('externalplayers') == 'true';
+        };
+
+        return appSettings;
+    }
+
+    function getDialogText() {
+        return function (globalize) {
+            return {
+                get: function (text) {
+                    return globalize.translate('Button' + text);
+                }
+            };
+        };
+    }
+
+    function initRequireWithBrowser(browser) {
+
+        var bowerPath = getBowerPath();
+
+        var embyWebComponentsBowerPath = bowerPath + '/emby-webcomponents';
+
+        if (browser.mobile || browser.msie) {
+            define("prompt", [embyWebComponentsBowerPath + "/prompt/nativeprompt"], returnFirstDependency);
+            define("confirm", [embyWebComponentsBowerPath + "/confirm/nativeconfirm"], returnFirstDependency);
+            define("alert", [embyWebComponentsBowerPath + "/alert/nativealert"], returnFirstDependency);
+        } else {
+            define("prompt", [embyWebComponentsBowerPath + "/prompt/prompt"], returnFirstDependency);
+            define("confirm", [embyWebComponentsBowerPath + "/confirm/confirm"], returnFirstDependency);
+            define("alert", [embyWebComponentsBowerPath + "/alert/alert"], returnFirstDependency);
+        }
     }
 
     function init(hostingAppInfo) {
@@ -2042,9 +1995,10 @@ var AppInfo = {};
 
         if (Dashboard.isRunningInCordova() && browserInfo.android) {
             if (MainActivity.getChromeVersion() >= 48) {
-                //define("audiorenderer", ["scripts/htmlmediarenderer"]);
-                define("audiorenderer", ["cordova/android/vlcplayer"]);
+                define("audiorenderer", ["scripts/htmlmediarenderer"]);
+                //define("audiorenderer", ["cordova/android/vlcplayer"]);
             } else {
+                window.VlcAudio = true;
                 define("audiorenderer", ["cordova/android/vlcplayer"]);
             }
             define("videorenderer", ["cordova/android/vlcplayer"]);
@@ -2095,8 +2049,6 @@ var AppInfo = {};
         deps.push('scripts/mediacontroller');
         deps.push('scripts/globalize');
 
-        deps.push('jQuery');
-
         deps.push('paper-drawer-panel');
 
         require(deps, function (events) {
@@ -2140,7 +2092,6 @@ var AppInfo = {};
         deps.push('connectionmanagerfactory');
         deps.push('credentialprovider');
 
-        deps.push('scripts/appsettings');
         deps.push('scripts/extensions');
 
         require(deps, function (connectionManagerExports, credentialProviderFactory) {
@@ -2150,26 +2101,14 @@ var AppInfo = {};
                 MediaBrowser[i] = connectionManagerExports[i];
             }
 
-            // TODO: This needs to be deprecated, but it's used heavily
-            $.fn.checked = function (value) {
-                if (value === true || value === false) {
-                    // Set the value of the checkbox
-                    return $(this).each(function () {
-                        this.checked = value;
-                    });
-                } else {
-                    // Return check state
-                    return this.length && this[0].checked;
-                }
-            };
-
             var promises = [];
             deps = [];
             deps.push('scripts/mediaplayer');
             deps.push('emby-icons');
             deps.push('paper-icon-button');
             deps.push('paper-button');
-            deps.push('thirdparty/jquerymobile-1.4.5/jquery.mobile.custom.js');
+            deps.push('jQuery');
+
             promises.push(getRequirePromise(deps));
 
             promises.push(Globalize.ensure());
@@ -2204,16 +2143,24 @@ var AppInfo = {};
                     depends = depends || [];
 
                     if (newHtml.indexOf('type-interior') != -1) {
-                        depends.push('jqmpopup');
-                        depends.push('jqmlistview');
-                        depends.push('jqmcollapsible');
-                        depends.push('jqmcontrolgroup');
-                        depends.push('jqmcheckbox');
-                        depends.push('scripts/notifications');
+                        addLegacyDependencies(depends, window.location.href);
                     }
 
                     require(depends, function () {
 
+                        // TODO: This needs to be deprecated, but it's used heavily
+                        $.fn.checked = function (value) {
+                            if (value === true || value === false) {
+                                // Set the value of the checkbox
+                                return $(this).each(function () {
+                                    this.checked = value;
+                                });
+                            } else {
+                                // Return check state
+                                return this.length && this[0].checked;
+                            }
+                        };
+
                         // Don't like having to use jQuery here, but it takes care of making sure that embedded script executes
                         $(mainDrawerPanelContent).html(Globalize.translateDocument(newHtml, 'html'));
                         onAppReady();
@@ -2243,6 +2190,8 @@ var AppInfo = {};
             deps.push('css!devices/android/android.css');
         } else if (AppInfo.isNativeApp && browserInfo.safari) {
             deps.push('css!devices/ios/ios.css');
+        } else if (AppInfo.isNativeApp && browserInfo.edge) {
+            deps.push('css!devices/windowsphone/wp.css');
         } else if (!browserInfo.android) {
             deps.push('css!devices/android/android.css');
         }
@@ -2260,6 +2209,7 @@ var AppInfo = {};
 
             if (browserInfo.android) {
                 deps.push('cordova/android/androidcredentials');
+                deps.push('cordova/android/links');
             }
         }
 
@@ -2269,12 +2219,10 @@ var AppInfo = {};
 
         deps.push('scripts/search');
         deps.push('scripts/librarylist');
-        deps.push('scripts/alphapicker');
-        deps.push('scripts/playlistmanager');
-        deps.push('scripts/sync');
         deps.push('scripts/backdrops');
         deps.push('scripts/librarymenu');
         deps.push('scripts/librarybrowser');
+        deps.push('jqm');
 
         deps.push('css!css/card.css');
 
@@ -2293,7 +2241,6 @@ var AppInfo = {};
             postInitDependencies.push('scripts/remotecontrol');
             postInitDependencies.push('css!css/notifications.css');
             postInitDependencies.push('css!css/chromecast.css');
-            postInitDependencies.push('apiclient-deferred');
 
             if (Dashboard.isRunningInCordova()) {
 
@@ -2349,11 +2296,14 @@ var AppInfo = {};
                     // Remove special characters
                     var cleanDeviceName = device.model.replace(/[^\w\s]/gi, '');
 
-                    var deviceId = window.MainActivity ? MainActivity.getLegacyDeviceId() : null;
-                    deviceId = deviceId || device.uuid;
+                    var deviceId = null;
+
+                    if (window.MainActivity) {
+                        deviceId = MainActivity.getLegacyDeviceId();
+                    }
 
                     resolve({
-                        deviceId: deviceId,
+                        deviceId: deviceId || device.uuid,
                         deviceName: cleanDeviceName,
                         appName: name,
                         appVersion: appVersion
@@ -2405,7 +2355,8 @@ var AppInfo = {};
                 });
             }
 
-            var deviceId = appStorage.getItem('_deviceId');
+            var deviceIdKey = '_deviceId1';
+            var deviceId = appStorage.getItem(deviceIdKey);
 
             if (deviceId) {
                 onDeviceAdAcquired(deviceId);
@@ -2416,7 +2367,7 @@ var AppInfo = {};
                     keys.push((navigator.cpuClass || ""));
                     keys.push(new Date().getTime());
                     var randomId = CryptoJS.SHA1(keys.join('|')).toString();
-                    appStorage.setItem('_deviceId', randomId);
+                    appStorage.setItem(deviceIdKey, randomId);
                     onDeviceAdAcquired(randomId);
                 });
             }
@@ -2447,6 +2398,8 @@ var AppInfo = {};
 
         require(initialDependencies, function (browser, appStorage) {
 
+            initRequireWithBrowser(browser);
+
             window.browserInfo = browser;
             window.appStorage = appStorage;
 
@@ -2469,6 +2422,22 @@ var AppInfo = {};
 
 })();
 
+function addLegacyDependencies(depends, url) {
+
+    var isPluginpage = url.toLowerCase().indexOf('/configurationpage?') != -1;
+
+    if (isPluginpage) {
+        depends.push('jqmpopup');
+        depends.push('jqmcollapsible');
+        depends.push('jqmcheckbox');
+        depends.push('legacy/dashboard');
+    }
+
+    depends.push('jqmcontrolgroup');
+    depends.push('jqmlistview');
+    depends.push('scripts/notifications');
+}
+
 function pageClassOn(eventName, className, fn) {
 
     document.addEventListener(eventName, function (e) {
